==> flexible-process-springboot-1.3.0.Final-sources.jar: org/kie/kogito/handlers/StateService_close_13_Handler.java <==
package org.kie.kogito.handlers;

import org.kie.kogito.process.workitem.WorkItemExecutionError;

@org.springframework.stereotype.Component()
public class StateService_close_13_Handler implements org.kie.kogito.internal.process.runtime.KogitoWorkItemHandler {

    org.kie.flexible.kogito.example.service.StateService service;

    public StateService_close_13_Handler() {
        this(new org.kie.flexible.kogito.example.service.StateService());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.context.annotation.Lazy()
    public StateService_close_13_Handler(org.kie.flexible.kogito.example.service.StateService service) {
        this.service = service;
    }

    public void executeWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
        java.lang.Object result;
        result = service.close((org.kie.flexible.kogito.example.model.SupportCase) workItem.getParameter("supportCase"), (Integer) workItem.getParameter("evaluation"), (String) workItem.getParameter("comment"));
        workItemManager.completeWorkItem(workItem.getStringId(), java.util.Collections.singletonMap("supportCase", result));
    }

    public void abortWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
    }

    public String getName() {
        return "org.kie.flexible.kogito.example.service.StateService_close_13_Handler";
    }
}

==> flexible-process-springboot-1.4.0.Final-sources.jar: org/kie/kogito/handlers/StateService_close_13_Handler.java <==
package org.kie.kogito.handlers;

import org.kie.kogito.process.workitem.WorkItemExecutionException;

@org.springframework.stereotype.Component()
public class StateService_close_13_Handler implements org.kie.kogito.internal.process.runtime.KogitoWorkItemHandler {

    org.kie.flexible.kogito.example.service.StateService service;

    public StateService_close_13_Handler() {
        this(new org.kie.flexible.kogito.example.service.StateService());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.context.annotation.Lazy()
    public StateService_close_13_Handler(org.kie.flexible.kogito.example.service.StateService service) {
        this.service = service;
    }

    public void executeWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
        java.lang.Object result;
        result = service.close((org.kie.flexible.kogito.example.model.SupportCase) workItem.getParameter("supportCase"), (Integer) workItem.getParameter("evaluation"), (String) workItem.getParameter("comment"));
        workItemManager.completeWorkItem(workItem.getStringId(), java.util.Collections.singletonMap("supportCase", result));
    }

    public void abortWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
    }

    public String getName() {
        return "org.kie.flexible.kogito.example.service.StateService_close_13_Handler";
    }
}
